@@ -1,7 +1,7 @@
 import re
 import requests
 from bs4 import BeautifulSoup
-from amazon_scraper import review_url, reviews_url, extract_review_id, dict_acceptable
+from amazon_scraper import review_url, reviews_url, extract_review_id, dict_acceptable, retry
 
 
 class Reviews(object):
@@ -16,9 +16,15 @@ class Reviews(object):
         if not URL:
             raise ValueError('Invalid review page parameters')
 
-        r = requests.get(URL)
-        r.raise_for_status()
-        self.soup = BeautifulSoup(r.text, 'html.parser')
+        self._URL = URL
+
+    @retry()
+    def soup(self):
+        if not self._soup:
+            r = requests.get(self._URL)
+            r.raise_for_status()
+            self._soup = BeautifulSoup(r.text, 'html.parser')
+        return self._soup
 
     def __iter__(self):
         page = self
